@@ -314,10 +314,10 @@ def complex_filter_calculator(smartquery, driver):
         logging.error(str(e))
 
 
-def nlp(nl, language="en", response_type="deanonymize", token="", env="dev", online=True, datasets=None, dataframe=None,
-        use_ner=None, use_cache=None, cache_mode=None, use_redis=None, use_specific_ner=None,
-        smartner_model_version=None, nl2query_model_version=None, query2sql_model_version=None,
-        similarity_threshold=None):
+def nlp(nl, language="en", response_type="deanonymize", token="", env="dev", online=True, workspace=None, datasets=None,
+        dataframe=None, use_ner=None, use_cache=None, cache_mode=None, use_redis=None, use_specific_ner=None,
+        use_fsn=None, smartner_model_version=None, nl2query_model_version=None, query2sql_model_version=None,
+        fields=None, similarity_threshold=None):
 
     # Check mode online/offline
     if datasets is not None and dataframe is not None:
@@ -329,14 +329,18 @@ def nlp(nl, language="en", response_type="deanonymize", token="", env="dev", onl
         online = True
 
     if online is True and not (nl != "" and datasets is not None and token != ""):
-        error = "!-!-! Online mode requires these inputs: natural language query, datasets IDs and authorization token."
+        error = "!-!-! Online mode requires these inputs: natural language query, datasets IDs and authorization token. !-!-!"
         print(error)
         return []
     elif online is False and not (nl != "" and dataframe is not None):
-        error = "!-!-! Offline mode requires these inputs: natural language query and dataframe."
+        error = "!-!-! Offline mode requires these inputs: natural language query and dataframe. !-!-!"
         print(error)
         return []
 
+    if (use_fsn and online) and workspace is None:
+        use_fsn = False
+        print("!-!-! FSN in online mode can't be used without the workspace. Setting use_fsn to False. !-!-!")
+
     headers = {
         "Content-Type": "application/json",
         "authorization": "Bearer " + token
@@ -364,7 +368,8 @@ def nlp(nl, language="en", response_type="deanonymize", token="", env="dev", onl
         "nl": nl,
         "lang": language,
         "datasets": datasets,
-        "dataframe": dataframe
+        "dataframe": dataframe,
+        "workspace": workspace
     }
 
     # Params check
@@ -373,52 +378,75 @@ def nlp(nl, language="en", response_type="deanonymize", token="", env="dev", onl
     if use_cache is not None:
         if use_cache not in [True, False]:
             use_cache = False
-            print("!-!-! Value of use_cache parameter not allowed. Setting to False.")
+            print("!-!-! Value of use_cache parameter not allowed. Setting to False. !-!-!")
         params["use_cache"] = use_cache
 
     if cache_mode is not None:
         if cache_mode not in ["standard", "similarity", "only_cache"]:
             cache_mode = "standard"
-            print("!-!-! Value of similarity_threshold parameter not allowed. Setting to 85%.")
+            print("!-!-! Value of similarity_threshold parameter not allowed. Setting to 85%. !-!-!")
         params["cache_mode"] = cache_mode
 
     if use_specific_ner is not None:
         if use_specific_ner not in [True, False]:
             use_specific_ner = False
-            print("!-!-! Value of use_specific_ner parameter not allowed. Setting to False.")
+            print("!-!-! Value of use_specific_ner parameter not allowed. Setting to False. !-!-!")
         params["use_specific_ner"] = use_specific_ner
 
+    if use_fsn is not None:
+        if use_fsn not in [True, False]:
+            use_fsn = False
+            print("!-!-! Value of use_fsn parameter not allowed. Setting to False. !-!-!")
+        params["use_fsn"] = use_fsn
+
+    if fields is not None:
+        to_delete = []
+        allowed_plh = ["dimensions", "measures", "dates"]
+        if type(fields) is not dict:
+            fields = {}
+            print("!-!-! Fields parameter must be a dictionary. Setting to empty dictionary. !-!-!")
+        else:
+            for key in fields.keys():
+                if key not in allowed_plh:
+                    to_delete.append(key)
+            if to_delete:
+                print("!-!-! Field keys: ", str(to_delete), "not allowed. Allowed keys:", str(allowed_plh) + ".",
+                      "This keys will be deleted. !-!-!")
+                for key in to_delete:
+                    del fields[key]
+        params["fields"] = fields
+
     if similarity_threshold is not None:
         if not (type(similarity_threshold) == int or type(similarity_threshold) == float):
             similarity_threshold = 0.85
-            print("!-!-! Value of similarity_threshold parameter not allowed. Setting to 85%.")
+            print("!-!-! Value of similarity_threshold parameter not allowed. Setting to 85%. !-!-!")
         params["similarity_threshold"] = similarity_threshold
 
     if response_type is not None:
         if response_type not in ["anonymize", "nl2query", "deanonymize", "query2sql"]:
             response_type = "deanonymize"
-            print("!-!-! Value of response_type parameter not allowed. Setting to deanonymize.")
+            print("!-!-! Value of response_type parameter not allowed. Setting to deanonymize. !-!-!")
         params["response_type"] = response_type
 
     if use_ner is not None:
         if use_ner not in [True, False]:
             use_ner = True
-            print("!-!-! Value of use_ner parameter not allowed. Setting to True.")
+            print("!-!-! Value of use_ner parameter not allowed. Setting to True. !-!-!")
         params["use_ner"] = use_ner
 
     # For now
     if use_redis is not None:
         if use_redis not in [True, False]:
             use_redis = False
-            print("!-!-! Value of use_redis parameter not allowed. Setting to False.")
+            print("!-!-! Value of use_redis parameter not allowed. Setting to False. !-!-!")
         elif use_redis is True:
             use_redis = False
-            print("!-!-! Warning: use_redis parameter not allowed for now. Setting to False.")
+            print("!-!-! Warning: use_redis parameter not allowed for now. Setting to False. !-!-!")
         params["use_redis"] = use_redis
 
     if online not in [True, False]:
         online = True
-        print("!-!-! Value of online parameter not allowed. Setting to True.")
+        print("!-!-! Value of online parameter not allowed. Setting to True. !-!-!")
     params["online"] = online
 
     if smartner_model_version is not None:
