@@ -40,9 +40,9 @@ if __name__ == "__main__":
         ]
     )
 
-    response = human2query.query2sql(smartquery=smartquery, driver="MySQL")
-    print(response)
-    response = human2query.complex_field_calculator(smartquery=smartquery, driver="MySQL")
-    print(response)
-    response = human2query.complex_filter_calculator(smartquery=smartquery, driver="MySQL")
+    response = human2query.query2sql(smartquery=smartquery, driver="MySQL", model_version="2022.10.06")
     print(response)
+    # response = human2query.complex_field_calculator(smartquery=smartquery, driver="MySQL")
+    # print(response)
+    # response = human2query.complex_filter_calculator(smartquery=smartquery, driver="MySQL")
+    # print(response)
