@@ -7,18 +7,20 @@ if __name__ == '__main__':
     field2 = Field(column='{{dimension.A}}', dataset='{{dataset.B}}', entityType="P_DIMENSION")
     field3 = Field(column='{{timeDimension.A}}', dataset='{{dataset.C}}', entityType="P_TIMEDIM", aggregation="year")
     field4 = Field(column="{{unknownDateDimension.A}}")
+    field5 = Field(complexExpression="A is better than B")
     from1 = From('{{dataset.A}}')
     from2 = From('{{dataset.B}}')
     from3 = From('{{dataset.C}}')
     condition1 = Condition(field4, "FROM", direction="NEXT", negate=True, steps="{{number.A}}",
-                           interval="{{timeDimension.B}}")
+                           interval="{{timeDimension.B}}", value=["{{contextTimeStart.A}}", "{{contextTimeEnd.A}}"])
     condition2 = Condition(field1, "LOE", ["{{number.B}}"])
     condition3 = Condition(field2, "IN", ["{{entity.A}}"])
     condition4 = Condition(field4, "RANGE", value=["{{timePeriodStart.A}}", "{{timePeriodEnd.A}}"])
+    condition5 = Condition(field5)
     sorting1 = Sorting("{{measure.A}}", SQLSorting.DESC)
     component = ChartComponent(type='chart', queryId="0", chartType='LINE')
-    query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3, condition4],
-                   orderBy=[sorting1], limit=10)
+    query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3, condition4, condition5],
+                   orderBy=[sorting1], limit=10, unmatched=[UnmatchedField(name="china", type="STRING", filter=False)])
     print(query1.to_sql())
     smartquery = SmartQuery(queries=[query1], components=[component])
     dump = jsons.dumps(smartquery)
